@@ -11,7 +11,7 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "mTunnel" multicast access service
 // Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
@@ -130,14 +130,14 @@ Socket* SocketLookupTable::Fetch(UsageEnvironment& env, Port port,
     if (sock == NULL) { // we need to create one:
       sock = CreateNew(env, port);
       if (sock == NULL || sock->socketNum() < 0) break;
-      
+
       fTable->Add((char*)(long)(port.num()), (void*)sock);
       isNew = True;
     }
-    
+
     return sock;
   } while (0);
-  
+
   delete sock;
   return NULL;
 }
