@@ -11,7 +11,7 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
 // Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
@@ -119,7 +119,7 @@ Boolean AMRAudioRTPSink
 unsigned AMRAudioRTPSink::specialHeaderSize() const {
   // For now, because we're packing only one frame per packet,
   // there's just a 1-byte payload header, plus a 1-byte TOC #####
-  return 2; 
+  return 2;
 }
 
 char const* AMRAudioRTPSink::auxSDPLine() {
