@@ -11,7 +11,7 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
 // Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
@@ -45,7 +45,7 @@ BasicUDPSource::~BasicUDPSource(){
 void BasicUDPSource::doGetNextFrame() {
   if (!fHaveStartedReading) {
     // Await incoming packets:
-    envir().taskScheduler().turnOnBackgroundReadHandling(fInputGS->socketNum(), 
+    envir().taskScheduler().turnOnBackgroundReadHandling(fInputGS->socketNum(),
 	 (TaskScheduler::BackgroundHandlerProc*)&incomingPacketHandler, this);
     fHaveStartedReading = True;
   }
@@ -67,7 +67,7 @@ void BasicUDPSource::incomingPacketHandler1() {
   // Read the packet into our desired destination:
   struct sockaddr_in fromAddress;
   if (!fInputGS->handleRead(fTo, fMaxSize, fFrameSize, fromAddress)) return;
-    
+
   // Tell our client that we have new data:
   afterGetting(this); // we're preceded by a net read; no infinite recursion
 }
