@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2007 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // Framed Sources
 // Implementation
 
@@ -116,4 +116,4 @@ void FramedSource::doStopGettingFrames() {
 unsigned FramedSource::maxFrameSize() const {
   // By default, this source has no maximum frame size.
   return 0;
-} 
+}
