@@ -11,7 +11,7 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
 // Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
@@ -86,6 +86,7 @@ void MPEG2TransportStreamFramer::doGetNextFrame() {
 void MPEG2TransportStreamFramer::doStopGettingFrames() {
   FramedFilter::doStopGettingFrames();
   fTSPacketCount = 0;
+  fTSPCRCount = 0;
 
   clearPIDStatusTable();
 }
@@ -184,7 +185,7 @@ void MPEG2TransportStreamFramer
 
   // Check whether we already have a record of a PCR for this PID:
   PIDStatus* pidStatus = (PIDStatus*)(fPIDStatusTable->Lookup((char*)pid));
-  
+
   if (pidStatus == NULL) {
     // We're seeing this PID's PCR for the first time:
     pidStatus = new PIDStatus(clock, timeNow);
@@ -201,7 +202,7 @@ void MPEG2TransportStreamFramer
     // (This can produce more accurate estimates for wildly VBR streams.)
     double meanPCRPeriod = 0.0;
     if (fTSPCRCount > 0) {
-      meanPCRPeriod=(double)fTSPacketCount/fTSPCRCount; 
+      meanPCRPeriod=(double)fTSPacketCount/fTSPCRCount;
       if (fTSPacketCount - pidStatus->lastPacketNum < meanPCRPeriod*PCR_PERIOD_VARIATION_RATIO) return;
     }
 
