@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2006 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // RTP sink for MPEG-4 Elementary Stream video (RFC 3016)
 // Implementation
 
@@ -122,7 +122,7 @@ char const* MPEG4ESVideoRTPSink::auxSDPLine() {
     endPtr += 2;
   }
   sprintf(endPtr, "\r\n");
-	  
+
   delete[] fAuxSDPLine;
   fAuxSDPLine = strDup(fmtp);
   delete[] fmtp;
