@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2007 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // A data structure that represents a session that consists of
 // potentially multiple (audio and/or video) sub-sessions
 // Implementation
@@ -108,12 +108,12 @@ Boolean MediaSession::initializeWithSDP(char const* sdpDescription) {
   char const* nextSDPLine;
   while (1) {
     if (!parseSDPLine(sdpLine, nextSDPLine)) return False;
-    //##### We should really check for: 
+    //##### We should really check for:
     // - "a=control:" attributes (to set the URL for aggregate control)
     // - the correct SDP version (v=0)
     if (sdpLine[0] == 'm') break;
     sdpLine = nextSDPLine;
-    if (sdpLine == NULL) break; // there are no m= lines at all 
+    if (sdpLine == NULL) break; // there are no m= lines at all
 
     // Check for various special SDP lines that we understand:
     if (parseSDPLine_s(sdpLine)) continue;
@@ -127,7 +127,7 @@ Boolean MediaSession::initializeWithSDP(char const* sdpDescription) {
     if (RealParseSDPAttributes(this, sdpLine)) continue;
 #endif
   }
-    
+
   while (sdpLine != NULL) {
     // We have a "m=" line, representing a new sub-session:
     MediaSubsession* subsession = new MediaSubsession(*this);
@@ -299,7 +299,7 @@ Boolean MediaSession::parseSDPLine_s(char const* sdpLine) {
   // Check for "s=<session name>" line
   char* buffer = strDupSize(sdpLine);
   Boolean parseSuccess = False;
-  
+
   if (sscanf(sdpLine, "s=%[^\r\n]", buffer) == 1) {
     delete[] fSessionName; fSessionName = strDup(buffer);
     parseSuccess = True;
@@ -313,7 +313,7 @@ Boolean MediaSession::parseSDPLine_i(char const* sdpLine) {
   // Check for "i=<session description>" line
   char* buffer = strDupSize(sdpLine);
   Boolean parseSuccess = False;
-  
+
   if (sscanf(sdpLine, "i=%[^\r\n]", buffer) == 1) {
     delete[] fSessionDescription; fSessionDescription = strDup(buffer);
     parseSuccess = True;
@@ -321,7 +321,7 @@ Boolean MediaSession::parseSDPLine_i(char const* sdpLine) {
   delete[] buffer;
 
   return parseSuccess;
-}  
+}
 
 Boolean MediaSession::parseSDPLine_c(char const* sdpLine) {
   // Check for "c=IN IP4 <connection-endpoint>"
@@ -352,8 +352,8 @@ Boolean MediaSession::parseSDPAttribute_type(char const* sdpLine) {
   return parseSuccess;
 }
 
-static Boolean parseRangeAttribute(char const* sdpLine, float& startTime, float& endTime) {
-  return sscanf(sdpLine, "a=range: npt = %g - %g", &startTime, &endTime) == 2;
+static Boolean parseRangeAttribute(char const* sdpLine, double& startTime, double& endTime) {
+  return sscanf(sdpLine, "a=range: npt = %lg - %lg", &startTime, &endTime) == 2;
 }
 
 Boolean MediaSession::parseSDPAttribute_control(char const* sdpLine) {
@@ -375,8 +375,8 @@ Boolean MediaSession::parseSDPAttribute_range(char const* sdpLine) {
   // (Later handle other kinds of "a=range" attributes also???#####)
   Boolean parseSuccess = False;
 
-  float playStartTime;
-  float playEndTime;
+  double playStartTime;
+  double playEndTime;
   if (parseRangeAttribute(sdpLine, playStartTime, playEndTime)) {
     parseSuccess = True;
     if (playStartTime > fMaxPlayStartTime) {
@@ -396,7 +396,7 @@ static Boolean parseSourceFilterAttribute(char const* sdpLine,
   // Note: At present, we don't check that <something> really matches
   // one of our multicast addresses.  We also don't support more than
   // one <source> #####
-  Boolean result = False; // until we succeed 
+  Boolean result = False; // until we succeed
   char* sourceName = strDupSize(sdpLine); // ensures we have enough space
   do {
     if (sscanf(sdpLine, "a=source-filter: incl IN IP4 %*s %s",
@@ -571,13 +571,13 @@ MediaSubsession::~MediaSubsession() {
 #endif
 }
 
-float MediaSubsession::playStartTime() const {
+double MediaSubsession::playStartTime() const {
   if (fPlayStartTime > 0) return fPlayStartTime;
 
   return fParent.playStartTime();
 }
 
-float MediaSubsession::playEndTime() const {
+double MediaSubsession::playEndTime() const {
   if (fPlayEndTime > 0) return fPlayEndTime;
 
   return fParent.playEndTime();
@@ -585,7 +585,7 @@ float MediaSubsession::playEndTime() const {
 
 Boolean MediaSubsession::initiate(int useSpecialRTPoffset) {
   if (fReadSource != NULL) return True; // has already been initiated
-  
+
   do {
     if (fCodecName == NULL) {
       env().setResultMsg("Codec is unspecified");
@@ -599,6 +599,7 @@ Boolean MediaSubsession::initiate(int useSpecialRTPoffset) {
     struct in_addr tempAddr;
     tempAddr.s_addr = connectionEndpointAddress();
         // This could get changed later, as a result of a RTSP "SETUP"
+    unsigned short firstRTPPortNum = fClientPortNum&~1;
     while (1) {
       unsigned short rtpPortNum = fClientPortNum&~1;
       if (isSSM()) {
@@ -627,7 +628,8 @@ Boolean MediaSubsession::initiate(int useSpecialRTPoffset) {
       // Try again:
       delete oldGroupsock;
       oldGroupsock = fRTPSocket;
-      fClientPortNum = 0;
+      if (firstRTPPortNum > 0) break; // Because we were told what port number to use, we can't choose another ourself
+      fClientPortNum += 2; // so that the OS doesn't choose the same port number again
     }
     delete oldGroupsock;
     if (!success) break;
@@ -699,12 +701,12 @@ Boolean MediaSubsession::initiate(int useSpecialRTPoffset) {
 	  = MP3ADURTPSource::createNew(env(), fRTPSocket, fRTPPayloadFormat,
 				       fRTPTimestampFrequency);
 	if (fRTPSource == NULL) break;
-	
+
 	// Add a filter that deinterleaves the ADUs after depacketizing them:
 	MP3ADUdeinterleaver* deinterleaver
 	  = MP3ADUdeinterleaver::createNew(env(), fRTPSource);
 	if (deinterleaver == NULL) break;
-	
+
 	// Add another filter that converts these ADUs to MP3 frames:
 	fReadSource = MP3FromADUSource::createNew(env(), deinterleaver);
       } else if (strcmp(fCodecName, "X-MP3-DRAFT-00") == 0) {
@@ -715,7 +717,7 @@ Boolean MediaSubsession::initiate(int useSpecialRTPoffset) {
 				       fRTPTimestampFrequency,
 				       "audio/MPA-ROBUST" /*hack*/);
 	if (fRTPSource == NULL) break;
-	
+
 	// Add a filter that converts these ADUs to MP3 frames:
 	fReadSource = MP3FromADUSource::createNew(env(), fRTPSource,
 						  False /*no ADU header*/);
@@ -822,7 +824,7 @@ Boolean MediaSubsession::initiate(int useSpecialRTPoffset) {
 	env().setResultMsg("RTP payload format unknown or not supported");
 	break;
       }
-      
+
       if (createSimpleRTPSource) {
 	char* mimeType
 	  = new char[strlen(mediumName()) + strlen(codecName()) + 2] ;
@@ -840,7 +842,7 @@ Boolean MediaSubsession::initiate(int useSpecialRTPoffset) {
       env().setResultMsg("Failed to create read source");
       break;
     }
-    
+
     // Finally, create our RTCP instance. (It starts running automatically)
     if (fRTPSource != NULL) {
       unsigned totSessionBandwidth = 500; // HACK - later get from SDP#####
@@ -888,7 +890,7 @@ Boolean MediaSubsession::setClientPortNum(unsigned short portNum) {
   return True;
 }
 
-unsigned MediaSubsession::connectionEndpointAddress() const {
+netAddressBits MediaSubsession::connectionEndpointAddress() const {
   do {
     // Get the endpoint name from with us, or our parent session:
     char const* endpointString = connectionEndpointName();
@@ -901,17 +903,17 @@ unsigned MediaSubsession::connectionEndpointAddress() const {
     NetAddressList addresses(endpointString);
     if (addresses.numAddresses() == 0) break;
 
-    return *(unsigned*)(addresses.firstAddress()->data());
+    return *(netAddressBits*)(addresses.firstAddress()->data());
   } while (0);
 
   // No address known:
   return 0;
 }
 
-void MediaSubsession::setDestinations(unsigned defaultDestAddress) {
+void MediaSubsession::setDestinations(netAddressBits defaultDestAddress) {
   // Get the destination address from the connection endpoint name
   // (This will be 0 if it's not known, in which case we use the default)
-  unsigned destAddress = connectionEndpointAddress();
+  netAddressBits destAddress = connectionEndpointAddress();
   if (destAddress == 0) destAddress = defaultDestAddress;
   struct in_addr destAddr; destAddr.s_addr = destAddress;
 
@@ -930,7 +932,7 @@ void MediaSubsession::setDestinations(unsigned defaultDestAddress) {
   }
 }
 
-float MediaSubsession::getNormalPlayTime(struct timeval const& presentationTime) {
+double MediaSubsession::getNormalPlayTime(struct timeval const& presentationTime) {
   // First, check whether our "RTPSource" object has already been synchronized using RTCP.
   // If it hasn't, then - as a special case - we need to use the RTP timestamp to compute the NPT.
   if (rtpSource() == NULL || rtpSource()->timestampFrequency() == 0) return 0.0; // no RTP source, or bad freq!
@@ -938,8 +940,8 @@ float MediaSubsession::getNormalPlayTime(struct timeval const& presentationTime)
   if (!rtpSource()->hasBeenSynchronizedUsingRTCP()) {
     if (!rtpInfo.infoIsNew) return 0.0; // the "rtpInfo" structure has not been filled in
     u_int32_t timestampOffset = rtpSource()->curPacketRTPTimestamp() - rtpInfo.timestamp;
-    float nptOffset = (timestampOffset/(float)(rtpSource()->timestampFrequency()))*scale();
-    float npt = playStartTime() + nptOffset;
+    double nptOffset = (timestampOffset/(double)(rtpSource()->timestampFrequency()))*scale();
+    double npt = playStartTime() + nptOffset;
 
     return npt;
   } else {
@@ -951,8 +953,8 @@ float MediaSubsession::getNormalPlayTime(struct timeval const& presentationTime)
       // This is the first time we've been called with a synchronized presentation time since the "rtpInfo"
       // structure was last filled in.  Use this "presentationTime" to compute "fNPT_PTS_Offset":
       u_int32_t timestampOffset = rtpSource()->curPacketRTPTimestamp() - rtpInfo.timestamp;
-      float nptOffset = (timestampOffset/(float)(rtpSource()->timestampFrequency()))*scale();
-      float npt = playStartTime() + nptOffset;
+      double nptOffset = (timestampOffset/(double)(rtpSource()->timestampFrequency()))*scale();
+      double npt = playStartTime() + nptOffset;
       fNPT_PTS_Offset = npt - ptsDouble*scale();
       rtpInfo.infoIsNew = False; // for next time
 
@@ -960,7 +962,7 @@ float MediaSubsession::getNormalPlayTime(struct timeval const& presentationTime)
     } else {
       // Use the precomputed "fNPT_PTS_Offset" to compute the NPT from the PTS:
       if (fNPT_PTS_Offset == 0.0) return 0.0; // error: The "rtpInfo" structure was apparently never filled in
-      return (float)(ptsDouble*scale() + fNPT_PTS_Offset);
+      return (double)(ptsDouble*scale() + fNPT_PTS_Offset);
     }
   }
 }
@@ -1034,8 +1036,8 @@ Boolean MediaSubsession::parseSDPAttribute_range(char const* sdpLine) {
   // (Later handle other kinds of "a=range" attributes also???#####)
   Boolean parseSuccess = False;
 
-  float playStartTime;
-  float playEndTime;
+  double playStartTime;
+  double playEndTime;
   if (parseRangeAttribute(sdpLine, playStartTime, playEndTime)) {
     parseSuccess = True;
     if (playStartTime > fPlayStartTime) {
@@ -1059,7 +1061,7 @@ Boolean MediaSubsession::parseSDPAttribute_fmtp(char const* sdpLine) {
   // Check for a "a=fmtp:" line:
   // TEMP: We check only for a handful of expected parameter names #####
   // Later: (i) check that payload format number matches; #####
-  //        (ii) look for other parameters also (generalize?) #####  
+  //        (ii) look for other parameters also (generalize?) #####
   do {
     if (strncmp(sdpLine, "a=fmtp:", 7) != 0) break; sdpLine += 7;
     while (isdigit(*sdpLine)) ++sdpLine;
@@ -1123,7 +1125,7 @@ Boolean MediaSubsession::parseSDPAttribute_fmtp(char const* sdpLine) {
 	delete[] fMode; fMode = strDup(valueStr);
       } else if (sscanf(sdpLine, " sprop-parameter-sets = %[^; \t\r\n]", valueStr) == 1) {
 	// Note: We used "sdpLine" here, because the value is case-sensitive.
-	delete[] fSpropParameterSets; fSpropParameterSets = strDup(valueStr); 
+	delete[] fSpropParameterSets; fSpropParameterSets = strDup(valueStr);
       } else {
 	// Some of the above parameters are Boolean.  Check whether the parameter
 	// names appear alone, without a "= 1" at the end:
