@@ -11,7 +11,7 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
 // A subclass of "RTSPServer" that creates "ServerMediaSession"s on demand,
@@ -56,11 +56,11 @@ DynamicRTSPServer::lookupServerMediaSession(char const* streamName) {
   // First, check whether the specified "streamName" exists as a local file:
   FILE* fid = fopen(streamName, "rb");
   Boolean fileExists = fid != NULL;
-  
+
   // Next, check whether we already have a "ServerMediaSession" for this file:
   ServerMediaSession* sms = RTSPServer::lookupServerMediaSession(streamName);
   Boolean smsExists = sms != NULL;
-  
+
   // Handle the four possibilities for "fileExists" and "smsExists":
   if (!fileExists) {
     if (smsExists) {
@@ -149,7 +149,7 @@ static ServerMediaSession* createNewSMS(UsageEnvironment& env,
     // change the following to True:
     Boolean convertToULaw = False;
     sms->addSubsession(WAVAudioFileServerMediaSubsession::createNew(env, fileName, reuseSource, convertToULaw));
-  } 
+  }
 
   return sms;
 }
