@@ -11,9 +11,9 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2006, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
 // A test program that reads an AMR audio file (as defined in RFC 3267)
 // and streams it using RTP
 // main program
@@ -114,7 +114,7 @@ void play() {
 	 << env->getResultMsg() << "\n";
     exit(1);
   }
-  
+
   // Finally, start playing:
   *env << "Beginning to read from file...\n";
   audioSink->startPlaying(*audioSource, afterPlaying, audioSink);
